SellOMatic_Item = LibStub("AceAddon-3.0"):NewAddon("SellOMatic_Item", "AceEvent-3.0", "AceConsole-3.0");
local SellOMatic = _G.SellOMatic
local item_tooltip = LibStub("LibGratuity-3.0");
local L = LibStub("AceLocale-3.0"):GetLocale("SellOMatic");

local function getOption(info)
	return (info.arg and SellOMatic.db.profile[info.arg] or SellOMatic.db.profile[info[#info]]);
end;

local function setOption(info, value)
	local key = info.arg or info[#info];
	SellOMatic.db.profile[key] = value;
end;

local item_options = {
	type = "group",
	name = "Item Options",
	args = {
		allowBoP = {
			name = "Sell BoP",
			desc = L["Toggle ON/OFF selling green soulbound items."],
			order = 1,
			type = "toggle",
			get = getOption,
			set = setOption,
		},
		allowBoE = {
			name = "Sell BoE",
			desc = "Toggle ON/OFF selling green bind on equip items.",
			order = 2,
			type = "toggle",
			get = getOption,
			set = setOption,
		},
		allowWhite = {
			name = "Sell common",
			desc = "Toggle ON/OFF selling common (white) items.",
			order = 3,
			type = "toggle",
			get = getOption,
			set = setOption,
		},
		allowGreen = {
			name = "Sell green",
			desc = "Toggle ON/OFF selling common (white) items.",
			order = 4,
			type = "toggle",
			get = getOption,
			set = setOption,
		}, 
		allowBlue = {
			name = "Allow Blue",
			desc = "Toggle ON/OFF selling blue quality items.",
			order = 5,
			type = "toggle",
			get = getOption,
			set = setOption,
		},
		allowEpic = {
			name = "Allow Epic",
			desc = "Toggle ON/OFF selling epic quality items.",
			order = 6,
			type = "toggle",
			get = getOption,
			set = setOption,
		},
		useILevel = {
			name = "Use iLevel",
			desc = "Toggles ON/OFF selling items by iLevel.",
			order = 8,
			type = "toggle",
			get = getOption,
			set = setOption,
		},
		iLevelValue = {
			name = "iLevel value",
			desc = "Items below the iLevel value set will be sold",
			order = 9,
			type = "range",
			min = 1,
			max = 200,
			step = 1,
			get = getOption,
			set = setOption,
		},
	},
}

function SellOMatic_Item:OnInitialize()
	LibStub("AceConfig-3.0"):RegisterOptionsTable("SellOMatic_Item", item_options);
	LibStub("AceConfigDialog-3.0"):AddToBlizOptions("SellOMatic_Item", "Item Options", "Sell-O-Matic");
end;

function SellOMatic:Scan_Item()
	local bag, slot, name, itemName, itemLink, itemRarity, itemSellPrice, itemStackCount, add;
	for bag = 0,4,1 do
		for slot = 1, GetContainerNumSlots(bag), 1 do
			add = 0;
			name = GetContainerItemLink(bag,slot);
			if name ~= nil then
				itemName, itemLink, itemRarity, itemLevel, _, _, _, itemStackCount, _, _, itemSellPrice = GetItemInfo(name);
				item_tooltip:SetBagItem(bag,slot);
				if itemRarity > 1 and item_tooltip:Find(ITEM_BIND_ON_EQUIP,1,3) and SellOMatic.db.profile.allowBoE or item_tooltip:Find(ITEM_SOULBOUND,1,3) and SellOMatic.db.profile.allowBoP then
					if itemRarity == 2 and SellOMatic.db.profile.allowGreen then
						add = 1;
					elseif itemRarity == 3 and SellOMatic.db.profile.allowBlue then
						add = 1;
					elseif itemRarity == 4 and SellOMatic.db.profile.allowEpic then
						add = 1;
					end;
				elseif itemRarity == 1 and SellOMatic.db.profile.allowWhite then
					add = 1;
				end;
				if add == 1 and SellOMatic.db.profile.useILevel then
					if itemLevel < SellOMatic.db.profile.iLevelValue then add = 0 end;
				end;
				if add == 1 then
					if itemStackCount > 1 then
						itemSellPrice = itemSellPrice * GetItemCount(itemName);
					end;
					SellOMatic:Add_Shopping_List(itemName, itemLink, itemRarity, itemLevel, itemSellPrice);
				end;
			end;
		end;
	end;
end;

--function SellOMatic_Item:Apply_iLevel()
--	local list = SellOMatic:Get_Shopping_List();
--	if list[1] ~= nil then
--		local i;
--		for i=1, #list, 1 do
--			if list[i][3] > 0 then
--				if list[i][4] < SellOMatic.db.profile.iLevelValue then
--					SellOMatic:Del_Shopping_List(i);
--				end;
--			end;
--		end;
--	end;
--end;
